@@ -626,7 +626,7 @@ int processfilter(void)
     fclose(stdin);
 
     if (num_pics != 1) {
-	fprintf(stderr, "gif2png: %d images in -1 (oneonly) mode\n", num_pics);
+	fprintf(stderr, "gif2png: %d images in -f (filter) mode\n", num_pics);
 	return 1;
     }
 
@@ -794,6 +794,7 @@ int main(int argc, char *argv[])
 		break;
 
 	    case 'f':
+	    case '1': /* backward compatibility */
 		filtermode = TRUE;
 		break;
 
@@ -850,6 +851,7 @@ int main(int argc, char *argv[])
 	"\n"
 	"   -b  replace background pels with given RRGGBB color (hex digits)\n"
 	"   -d  delete source GIF files after successful conversion\n"
+	"   -f  allow use as filter, die on multi-image GIF\n"
 	"   -g  write gamma=(1.0/2.2) and sRGB chunks\n"
 	"   -h  generate PNG histogram chunks into color output files\n"
 	"   -i  force conversion to interlaced PNG files\n"
@@ -857,11 +859,11 @@ int main(int argc, char *argv[])
 	"   -p  display progress of PNG writing in %%\n"
 	"   -r  try to recover corrupted GIF files\n"
 	"   -s  do not write Software text chunk\n"
-	"   -t  transparency OK, web probe mode wccepts transparent GIFs\n"
+	"   -t  transparency OK, web probe mode accepts transparent GIFs\n"
 	"   -v  verbose; display conversion statistics and debugging messages\n"
 	"   -w  web probe, list images without animation or transparency\n"
 	"   -O  optimize; remove unused color-table entries; use zlib level 9\n"
-	"   -1  one-only; allow use as filter, die on multi-image GIF\n"
+	"   -1  one-only; same as -f; provided for backward compatibility\n"
 	"\n"
 	"   If no source files are listed, stdin is converted to noname.png.\n"
 	"\n"
